@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -23,7 +23,6 @@ use EBox::Exceptions::DeprecatedMethod;
 use POSIX qw(setuid setgid setlocale LC_ALL LC_NUMERIC);
 use English;
 
-use constant CHECK_DBUS_CMD =>'ebox-dbus-check';
 use constant LOGGER_CAT => 'EBox';
 
 my $loginit = 0;
@@ -122,58 +121,25 @@ sub locale
 
 sub init
 {
-	POSIX::setlocale(LC_ALL, EBox::locale());
-	POSIX::setlocale(LC_NUMERIC, 'C');
+    POSIX::setlocale(LC_ALL, EBox::locale());
+    POSIX::setlocale(LC_NUMERIC, 'C');
 
-	my @groups = @{EBox::Config::groups()};
-	my $gids = '';
-	for my $group (@groups) {
-		$gids .= getgrnam($group) . ' ';
-	}
-	$GID = $EGID = getgrnam(EBox::Config::group()) . " $gids";
+    my @groups = @{EBox::Config::groups()};
+    my $gids = '';
+    for my $group (@groups) {
+        $gids .= getgrnam($group) . ' ';
+    }
+    $GID = $EGID = getgrnam(EBox::Config::group()) . " $gids";
 
-	my $user = EBox::Config::user();
-	my $uid = getpwnam($user);
-	setuid($uid) or die "Cannot change user to $user. Are you root?";
+    my $user = EBox::Config::user();
+    my $uid = getpwnam($user);
+    setuid($uid) or die "Cannot change user to $user. Are you root?";
 
-        EBox::initLogger('eboxlog.conf');
-        dbusInit();
+    EBox::initLogger('eboxlog.conf');
 
-        # Set HOME environment variable to avoid some issues calling
-        # external programs
-        $ENV{HOME} = EBox::Config::home();
-}
-
-# Method: dbusInit
-#
-#      Initialise a dbus daemon, if it's not already done. We store
-#      one for root and one for eBox user.
-#
-#
-sub dbusInit
-{
-	my $gconfversion = `gconftool-2 -v`;
-	$gconfversion =~ m/^(\d+)\.(\d+)\./;
-	my $minor = $2;
-	if ($minor <= 22) {
-		return;
-	}
-
-	my $confFile;
-	if ( POSIX::getuid() == 0) {
-		$confFile = EBox::Config::conf() . 'dbus-root-session.conf';
-	} else {
-		$confFile = EBox::Config::conf() . 'dbus-ebox-session.conf';
-	}
-
-	for my $i (1..30) {
-		# Check we actually can connect to dbus
-        system( EBox::Config::pkgdata() .  CHECK_DBUS_CMD);
-		last if ( $? == 0 );
-		sleep(1);
-	}
-	my $dbusAddress = EBox::Config::configkeyFromFile('DBUS_SESSION_BUS_ADDRESS', $confFile);
-	$ENV{DBUS_SESSION_BUS_ADDRESS} = $dbusAddress;
+    # Set HOME environment variable to avoid some issues calling
+    # external programs
+    $ENV{HOME} = EBox::Config::home();
 }
 
 1;
