@@ -1,5 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -144,22 +143,22 @@ sub _body
 
 
 MASON_INTERP: {
-  my $masonInterp;
+    my $masonInterp;
 
-  sub _masonInterp
+    sub _masonInterp
     {
-      my ($self) = @_;
+        my ($self) = @_;
 
-      return $masonInterp if defined $masonInterp;
+        return $masonInterp if defined $masonInterp;
 
-      $masonInterp = HTML::Mason::Interp->new(
-					      comp_root => EBox::Config::templates,
-#					      default_escape_flags => 'h',
-					     );
-
-      return $masonInterp;
+        $masonInterp = HTML::Mason::Interp->new(
+            comp_root => EBox::Config::templates,
+            escape_flags => {
+                h => \&HTML::Mason::Escapes::basic_html_escape,
+            },
+        );
+        return $masonInterp;
     }
-
 };
 
 sub _footer
@@ -258,6 +257,7 @@ sub run
 	}
 	else {
 	  try {
+	    $self->_validateReferer();
 	    settextdomain($self->domain());
 	    $self->_process();
 	  }
@@ -514,7 +514,7 @@ sub _process
 
 	$self->_validateParams();
 	$self->actuate();
-      $self->{params} = $self->masonParameters();
+	$self->{params} = $self->masonParameters();
 }
 
 # Method: setMsg
@@ -574,7 +574,7 @@ sub setErrorFromException
     }
     else {
 	$self->{error} = __("You have just hit a bug ".
-			    "in eBox. Please seek technical ".
+			    "in Zentyal. Please seek technical ".
 			    "support.");
     }
 }
@@ -651,22 +651,52 @@ sub paramsAsHash
 
 sub _validateParams
 {
-
     my ($self) = @_;
     my $params_r    = $self->params();
     $params_r       = $self->_validateRequiredParams($params_r);
     $params_r       = $self->_validateOptionalParams($params_r);
+    $params_r       = $self->_webkitParamsWorkaround($params_r);
 
     my @paramsLeft = @{ $params_r };
-    if (@paramsLeft ) {
-      EBox::error("Unallowed parameters found in CGI request: @paramsLeft");
-      throw EBox::Exceptions::External ( __('Your request could not be processed because it had some incorrect parameters'));
+    if (@paramsLeft) {
+        EBox::error("Unallowed parameters found in CGI request: @paramsLeft");
+        throw EBox::Exceptions::External ( __('Your request could not be processed because it had some incorrect parameters'));
     }
 
     return 1;
 }
 
 
+sub _validateReferer
+{
+    my ($self) = @_;
+
+    # Only check if the client sends params
+    if ( ! @{$self->params()} ) {
+        return;
+    }
+
+    my $referer = $ENV{HTTP_REFERER};
+    my $hostname = $ENV{HTTP_HOST};
+    my $rshostname = $ENV{HTTP_HOST};
+
+    # allow remoteservices proxy access
+    # proxy is a valid subdomain of {domain}
+    if ( EBox::Global->modExists('remoteservices') ) {
+        my $rs = EBox::Global->modInstance('remoteservices');
+
+        if ( $rs->isConnected() ) {
+            $rshostname = $rs->proxyDomain();
+        }
+    }
+    if ( $referer =~ m/^https:\/\/$hostname(:[0-9]*)?\// or
+         $referer =~ m/^https:\/\/[^\/]*$rshostname(:[0-9]*)?\// ) {
+        return; # everithing ok
+    }
+    throw EBox::Exceptions::External( __("Wrong HTTP referer detected, operation cancelled for security reasons"));
+}
+
+
 sub _validateRequiredParams
 {
     my ($self, $params_r) = @_;
@@ -698,6 +728,20 @@ sub _validateOptionalParams
 }
 
 
+sub _webkitParamsWorkaround
+{
+    my ($self, $params_r) = @_;
+
+    # Prototype adds a '_' empty param to Ajax POST requests when the agent is
+    # webkit based
+    my @paramsToDiscard = ['_'];
+    my $matchResult_r = _matchParams(@paramsToDiscard, $params_r);
+
+    my $allMatches = all  @{ $matchResult_r->{matches} };
+    my @newParams = grep { $_ ne $allMatches } @{ $params_r} ;
+    return \@newParams;
+}
+
 sub _matchParams
 {
     my ($targetParams_r, $actualParams_r) = @_;
