@@ -1,5 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
-# Copyright (C) 2009 eBox Technologies S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -181,8 +180,6 @@ sub _root
             }
             _rootError($sudocmd, $commands, $ret, \@output, \@error);
         }
-    } else {
-        unlink($cmdFile);
     }
 
     return \@output;
@@ -350,7 +347,7 @@ sub fileTest
     ($test eq $anyFileTestPredicate) or throw EBox::Exceptions::Internal("Unknown or unsupported test file predicate: $test (upon $file)");
 
     my $testCmd = "$TEST_PATH $test '$file'";
-    rootWithoutException($testCmd);
+    silentRoot($testCmd);
 
     return ($? == 0);           # $? was set by execution of $testCmd
 }
