@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -24,6 +24,7 @@ use EBox::Gettext;
 use EBox::NetWrappers qw();
 use Net::IP;
 use Mail::RFC822::Address;
+use Data::Validate::Domain qw(is_hostname);
 
 use constant IFNAMSIZ => 16; #Max length name for interfaces
 
@@ -49,7 +50,6 @@ BEGIN {
         $VERSION = EBox::Config::version;
 }
 
-#
 # Function: isIPInNetwork
 #
 #   Checks if an IP is within a given network address and its masks
@@ -66,16 +66,15 @@ BEGIN {
 #
 sub isIPInNetwork # net_ip, net_mask, host_ip
 {
-        my ($net_ip, $net_mask, $host_ip) = @_;
-        my $net_net = EBox::NetWrappers::ip_network($net_ip, $net_mask);
+    my ($net_ip, $net_mask, $host_ip) = @_;
+    my $net_net = EBox::NetWrappers::ip_network($net_ip, $net_mask);
 
-        my $bits = EBox::NetWrappers::bits_from_mask($net_mask);
-        my $ip = new Net::IP("$net_net/$bits");
-        my $ip2 = new Net::IP($host_ip);
-        return ($ip2->overlaps($ip)==$IP_A_IN_B_OVERLAP);
+    my $bits = EBox::NetWrappers::bits_from_mask($net_mask);
+    my $ip = new Net::IP("$net_net/$bits");
+    my $ip2 = new Net::IP($host_ip);
+    return ($ip2->overlaps($ip)==$IP_A_IN_B_OVERLAP);
 }
 
-#
 # Function: checkCIDR
 #
 #       Check the validity for a given CIDR block
@@ -97,41 +96,39 @@ sub isIPInNetwork # net_ip, net_mask, host_ip
 #
 sub checkCIDR # (cidr, name?)
 {
-        my $cidr = shift;
-        my $name = shift;
+    my $cidr = shift;
+    my $name = shift;
 
-        my $ip;
+    my $ip;
 
-        my @values = split(/\//, $cidr);
+    my @values = split(/\//, $cidr);
 
-        if(@values == 2) {
-                my ($address,$mask)  = @values;
-                if(checkIP($address)) {
-                        my $netmask = EBox::NetWrappers::mask_from_bits($mask);
-                        if($netmask){
-                                my $network = EBox::NetWrappers::ip_network($address, $netmask);
-                                if ($network eq $address) {
-                                        $ip = new Net::IP("$network/$mask");
-                                }
-
-                        }
+    if(@values == 2) {
+        my ($address,$mask)  = @values;
+        if(checkIP($address)) {
+            my $netmask = EBox::NetWrappers::mask_from_bits($mask);
+            if($netmask){
+                my $network = EBox::NetWrappers::ip_network($address, $netmask);
+                if ($network eq $address) {
+                    $ip = new Net::IP("$network/$mask");
                 }
+
+            }
         }
+    }
 
-        unless($ip) {
-                if ($name) {
-                        throw EBox::Exceptions::InvalidData
-                                ('data' => $name, 'value' => $cidr);
-                } else {
-                        return undef;
-                }
+    unless($ip) {
+        if ($name) {
+            throw EBox::Exceptions::InvalidData
+                ('data' => $name, 'value' => $cidr);
+        } else {
+            return undef;
         }
+    }
 
-
-        return 1;
+    return 1;
 }
 
-#
 # Function: checkIP
 #
 #       Checks if the string param that holds an ip address is a valid
@@ -154,24 +151,23 @@ sub checkCIDR # (cidr, name?)
 #
 sub checkIP # (ip, name?)
 {
-        my $ip = shift;
-        my $name = shift;
+    my $ip = shift;
+    my $name = shift;
 
-        if("$ip\." =~ m/^(([01]?[0-9][0-9]?|2[0-4][0-9]|25[0-5])\.){4}$/){
-                my $first = (split(/\./, $ip))[0];
-                if(($first != 0) and ($first < 224)) {
-                        return 1;
-                }
-        }
-        if ($name) {
-                throw EBox::Exceptions::InvalidData
-                        ('data' => $name, 'value' => $ip);
-        } else {
-                return undef;
+    if("$ip\." =~ m/^(([01]?[0-9][0-9]?|2[0-4][0-9]|25[0-5])\.){4}$/){
+        my $first = (split(/\./, $ip))[0];
+        if(($first != 0) and ($first < 224)) {
+            return 1;
         }
+    }
+    if ($name) {
+        throw EBox::Exceptions::InvalidData
+            ('data' => $name, 'value' => $ip);
+    } else {
+        return undef;
+    }
 }
 
-#
 # Function: checkIP6
 #
 #       Checks if the string param that holds an ip address is a valid
@@ -194,22 +190,21 @@ sub checkIP # (ip, name?)
 #
 sub checkIP6 # (ip, name?)
 {
-   my ($ip, $name) = @_;
+    my ($ip, $name) = @_;
 
-   if (Net::IP::ip_is_ipv6($ip)) {
-     return 1;
-   }
+    if (Net::IP::ip_is_ipv6($ip)) {
+        return 1;
+    }
 
-   if ($name) {
-     throw EBox::Exceptions::InvalidData
-       ('data' => $name, 'value' => $ip);
-   } else {
-     return undef;
-   }
+    if ($name) {
+        throw EBox::Exceptions::InvalidData
+            ('data' => $name, 'value' => $ip);
+    } else {
+        return undef;
+    }
 }
 
 
-#
 # Function: checkNetmask
 #
 #       Checks if the string param that holds a network mask is valid .
@@ -231,31 +226,31 @@ sub checkIP6 # (ip, name?)
 #
 sub checkNetmask # (mask, name?)
 {
-        my $nmask = shift;
-        my $name = shift;
-        my $error;
+    my $nmask = shift;
+    my $name = shift;
+    my $error;
 
-        if("$nmask\." =~ m/^(([01]?[0-9][0-9]?|2[0-4][0-9]|25[0-5])\.){4}$/){
-                my $bits;
-                foreach (split(/\./, $nmask)){
-                        $bits .= unpack( "B*", pack( "C", $_ ));
-                }
-                unless ($bits =~ /^((0+)|(1+0*))$/){
-                        $error = 1;
-                }
+    if("$nmask\." =~ m/^(([01]?[0-9][0-9]?|2[0-4][0-9]|25[0-5])\.){4}$/){
+        my $bits;
+        foreach (split(/\./, $nmask)){
+            $bits .= unpack( "B*", pack( "C", $_ ));
+        }
+        unless ($bits =~ /^((0+)|(1+0*))$/){
+            $error = 1;
+        }
+    } else {
+        $error = 1;
+    }
+
+    if ($error) {
+        if ($name) {
+            throw EBox::Exceptions::InvalidData
+                ('data' => $name, 'value' => $nmask);
         } else {
-                $error = 1;
+            return undef;
         }
-
-        if ($error) {
-                if ($name) {
-                        throw EBox::Exceptions::InvalidData
-                                ('data' => $name, 'value' => $nmask);
-                } else {
-                        return undef;
-                }
-        }
-        return 1;
+    }
+    return 1;
 }
 
 #
@@ -285,37 +280,36 @@ sub checkNetmask # (mask, name?)
 #
 sub checkIPNetmask # (ip, mask, name_ip?, name_mask?)
 {
-        my ($ip,$mask,$name_ip, $name_mask) = @_;
-        my $error = 0;
+    my ($ip,$mask,$name_ip, $name_mask) = @_;
+    my $error = 0;
 
-        checkIP($ip,$name_ip);
-        if ($mask eq '255.255.255.255') {
-            return 1;
-        }
-        checkNetmask($mask,$name_mask);
-
-        my $ip_bpack = pack("CCCC", split(/\./, $ip));
-        my $mask_bpack = pack("CCCC", split(/\./, $mask));
-
-        my $net_bits .= unpack("B*", $ip_bpack & (~$mask_bpack));
-        my $broad_bits .= unpack("B*", $ip_bpack | $mask_bpack);
-
-        if(($net_bits =~ /^0+$/) or ($broad_bits =~ /^1+$/)){
-                $error = 1;
-        }
-        if ($error) {
-                if ($name_ip) {
-                        throw EBox::Exceptions::InvalidData
-                                ('data' => $name_ip . "/" . $name_mask,
-                                 'value' => $ip . "/" . $mask);
-                } else {
-                        return undef;
-                }
-        }
+    checkIP($ip,$name_ip);
+    if ($mask eq '255.255.255.255') {
         return 1;
+    }
+    checkNetmask($mask,$name_mask);
+
+    my $ip_bpack = pack("CCCC", split(/\./, $ip));
+    my $mask_bpack = pack("CCCC", split(/\./, $mask));
+
+    my $net_bits .= unpack("B*", $ip_bpack & (~$mask_bpack));
+    my $broad_bits .= unpack("B*", $ip_bpack | $mask_bpack);
+
+    if(($net_bits =~ /^0+$/) or ($broad_bits =~ /^1+$/)){
+        $error = 1;
+    }
+    if ($error) {
+        if ($name_ip) {
+            throw EBox::Exceptions::InvalidData
+                ('data' => $name_ip . "/" . $name_mask,
+                 'value' => $ip . "/" . $mask);
+        } else {
+            return undef;
+        }
+    }
+    return 1;
 }
 
-#
 # Function: checkPort
 #
 #       Check if the given port is valid
@@ -337,28 +331,28 @@ sub checkIPNetmask # (ip, mask, name_ip?, name_mask?)
 #
 sub checkPort # (port, name?)
 {
-        my $pnumber = shift;
-        my $name = shift;
+    my $pnumber = shift;
+    my $name = shift;
 
-        unless($pnumber =~/^\d+$/){
-                if ($name) {
-                        throw EBox::Exceptions::InvalidData
-                                ('data' => $name, 'value' => $pnumber);
-                } else {
-                        return undef;
-                }
-        }
-
-        if (($pnumber > 0) and ($pnumber <= 65535)) {
-                return 1;
+    unless($pnumber =~/^\d+$/){
+        if ($name) {
+            throw EBox::Exceptions::InvalidData
+                ('data' => $name, 'value' => $pnumber);
         } else {
-                if ($name) {
-                        throw EBox::Exceptions::InvalidData
-                                ('data' => $name, 'value' => $pnumber);
-                } else {
-                        return undef;
-                }
+            return undef;
         }
+    }
+
+    if (($pnumber > 0) and ($pnumber <= 65535)) {
+        return 1;
+    } else {
+        if ($name) {
+            throw EBox::Exceptions::InvalidData
+                ('data' => $name, 'value' => $pnumber);
+        } else {
+            return undef;
+        }
+    }
 }
 
 #
@@ -384,38 +378,37 @@ sub checkPort # (port, name?)
 #
 sub checkVlanID # (id, name?)
 {
-        my $id = shift;
-        my $name = shift;
+    my $id = shift;
+    my $name = shift;
 
-        unless($id =~/^\d+$/){
-                if ($name) {
-                        throw EBox::Exceptions::InvalidData
-                                ('data' => $name,
-                                 'value' => $id,
-                                 'advice' =>
-                                 __('Must be a number between 1 and 4096')
-                                );
-                } else {
-                        return undef;
-                }
-        }
-
-        if (($id > 0) && ($id <= 4096)) {
-                return 1;
+    unless($id =~/^\d+$/){
+        if ($name) {
+            throw EBox::Exceptions::InvalidData
+                ('data' => $name,
+                 'value' => $id,
+                 'advice' =>
+                 __('Must be a number between 1 and 4096')
+                );
         } else {
-                if ($name) {
-                        throw EBox::Exceptions::InvalidData
-                                ('data' => $name, 'value' => $id,
-                                 'advice' =>
-                                 __('Must be a number between 1 and 4096')
-                                );
-                } else {
-                        return undef;
-                }
+            return undef;
         }
+    }
+
+    if (($id > 0) && ($id <= 4096)) {
+        return 1;
+    } else {
+        if ($name) {
+            throw EBox::Exceptions::InvalidData
+                ('data' => $name, 'value' => $id,
+                 'advice' =>
+                 __('Must be a number between 1 and 4096')
+                );
+        } else {
+            return undef;
+        }
+    }
 }
 
-#
 # Function: checkProtocol
 #
 #       Checks if the given protocol is valid (tcp or udp)
@@ -437,29 +430,29 @@ sub checkVlanID # (id, name?)
 #
 sub checkProtocol # (protocol, name?)
 {
-        my $proto = shift;
-        my $name = shift;
+    my $proto = shift;
+    my $name = shift;
 
-        # FIXME: Ask for them to <EBox::Types::Service> -> Double dependency
-        if ($proto eq 'tcp' ) {
-                return 1;
-        } elsif ($proto eq 'udp' ) {
-                return 1;
-        } elsif ($proto eq 'all' ) {
-                return 1;
-        } elsif ($proto eq 'icmp') {
-                return 1;
-        } elsif ($proto eq 'gre' ) {
-                return 1;
-        }
-        else {
-                if ($name) {
-                        throw EBox::Exceptions::InvalidData
-                                ('data' => $name, 'value' => $proto);
-                } else {
-                        return undef;
-                }
+    # FIXME: Ask for them to <EBox::Types::Service> -> Double dependency
+    if ($proto eq 'tcp' ) {
+        return 1;
+    } elsif ($proto eq 'udp' ) {
+        return 1;
+    } elsif ($proto eq 'all' ) {
+        return 1;
+    } elsif ($proto eq 'icmp') {
+        return 1;
+    } elsif ($proto eq 'gre' ) {
+        return 1;
+    }
+    else {
+        if ($name) {
+            throw EBox::Exceptions::InvalidData
+                ('data' => $name, 'value' => $proto);
+        } else {
+            return undef;
         }
+    }
 }
 
 #
@@ -484,23 +477,21 @@ sub checkProtocol # (protocol, name?)
 #
 sub checkMAC # (mac, name?)
 {
-        my $mac = shift || '';
-        my $name = shift;
-        $mac .= ':';
-        unless ($mac =~ /^([0-9a-fA-F]{1,2}:){6}$/) {
-                if ($name) {
-                        throw EBox::Exceptions::InvalidData
-                                ('data' => $name, 'value' => $mac);
-                } else {
-                        return undef;
-                }
+    my $mac = shift || '';
+    my $name = shift;
+    $mac .= ':';
+    unless ($mac =~ /^([0-9a-fA-F]{1,2}:){6}$/) {
+        if ($name) {
+            throw EBox::Exceptions::InvalidData
+                ('data' => $name, 'value' => $mac);
+        } else {
+            return undef;
         }
+    }
 
-        return 1;
-
+    return 1;
 }
 
-#
 # Function: checkVifaceName
 #
 #       Checks if a virtual interface name is correct. The whole name's length
@@ -526,20 +517,20 @@ sub checkMAC # (mac, name?)
 
 sub checkVifaceName # (real, virtual, name?)
 {
-        my $iface  = shift;
-        my $viface = shift;
-        my $name   = shift;
+    my $iface  = shift;
+    my $viface = shift;
+    my $name   = shift;
 
-        my $fullname = $iface . ":" . $viface;
-        unless (($viface =~ /^\w+$/) and (length($fullname) < IFNAMSIZ)){
-                if ($name) {
-                        throw EBox::Exceptions::InvalidData
-                                ('data' => $name, 'value' => $viface);
-                } else {
-                        return undef;
-                }
+    my $fullname = $iface . ":" . $viface;
+    unless (($viface =~ /^\w+$/) and (length($fullname) < IFNAMSIZ)){
+        if ($name) {
+            throw EBox::Exceptions::InvalidData
+                ('data' => $name, 'value' => $viface);
+        } else {
+            return undef;
         }
-        return 1;
+    }
+    return 1;
 }
 
 # Function: checkName
@@ -562,25 +553,22 @@ sub checkVifaceName # (real, virtual, name?)
 #
 sub checkName # (name)
 {
-        my $name = shift;
-        (length($name) <= 20) or return undef;
-        (length($name) > 0) or return undef;
-        ($name =~ /^[\d_]/) and return undef;
-        ($name =~ /^\w/) or return undef;
-        ($name =~ /\W/) and return undef;
-        return 1;
+    my $name = shift;
+    (length($name) <= 20) or return undef;
+    (length($name) > 0) or return undef;
+    ($name =~ /^[\d_]/) and return undef;
+    ($name =~ /^\w/) or return undef;
+    ($name =~ /\W/) and return undef;
+    return 1;
 }
 
-sub _checkDomainName {
-        my $d = shift;
-        ($d =~ /^\w/) or return undef;
-        ($d =~ /\w$/) or return undef;
-        ($d =~ /\.-/) and return undef;
-        ($d =~ /-\./) and return undef;
-        ($d =~ /\.\./) and return undef;
-        ($d =~ /_/) and return undef;
-        ($d =~ /^[-\.\w]+$/) or return undef;
-        return 1;
+# TODO: Remove this once the call from the mail wizard is changed
+# to the checkDomainName public function
+sub _checkDomainName
+{
+    my ($domain) = @_;
+
+    return is_hostname($domain);
 }
 
 # Function: checkDomainName
@@ -598,18 +586,17 @@ sub _checkDomainName {
 #
 sub checkDomainName # (domain, name?)
 {
-        my $domain = shift;
-        my $name = shift;
+    my ($domain, $name) = @_;
 
-        unless (_checkDomainName($domain)) {
-                if ($name) {
-                        throw EBox::Exceptions::InvalidData
-                                ('data' => $name, 'value' => $domain);
-                } else {
-                        return undef;
-                }
+    unless (is_hostname($domain)) {
+        if ($name) {
+            throw EBox::Exceptions::InvalidData
+                ('data' => $name, 'value' => $domain);
+        } else {
+            return undef;
         }
-        return 1;
+    }
+    return 1;
 }
 
 
@@ -630,18 +617,18 @@ sub checkDomainName # (domain, name?)
 #
 sub checkHost # (domain, name?)
 {
-  my ($host, $name) = @_;
-# if the host is made only of numbers and points we checki it as a IP address otherwise we check it as a hostname
-   if ( $host =~ m/^[\d.]+$/ ) {
-    return checkIP($host, $name);
-  }
-  else {
-    return checkDomainName($host, $name);
-  }
+    my ($host, $name) = @_;
 
+    # if the host is made only of numbers and points we check it
+    # as a IP address otherwise we check it as a hostname
+    if ( $host =~ m/^[\d.]+$/ ) {
+        return checkIP($host, $name);
+    }
+    else {
+        return checkDomainName($host, $name);
+    }
 }
 
-#
 # Function: checkEmailAddress
 #
 #       Check the validity for a given FQDN email address
@@ -664,18 +651,18 @@ sub checkHost # (domain, name?)
 #
 sub checkEmailAddress
 {
-  my ($address, $name) = @_;
+    my ($address, $name) = @_;
 
-  unless ( Mail::RFC822::Address::valid($address)) {
-    if ($name) {
-      throw EBox::Exceptions::InvalidData
-        ('data' => $name, 'value' => $address);
-    } else {
-      return undef;
+    unless (Mail::RFC822::Address::valid($address)) {
+        if ($name) {
+            throw EBox::Exceptions::InvalidData
+                ('data' => $name, 'value' => $address);
+        } else {
+            return undef;
+        }
     }
-  }
 
-  return 1;
+    return 1;
 }
 
 
@@ -693,22 +680,22 @@ sub checkEmailAddress
 #
 sub isPrivateDir
 {
-  my ($dir, $throwException) = @_;
+    my ($dir, $throwException) = @_;
 
-  my @stat = stat($dir) ;
-  if (@stat == 0) {
-    throw EBox::Exceptions::External (__x("Cannot stat dir: {dir}. This may mean that the directory does not exist or the permissions forbid access to it", dir => $dir)) if $throwException;
-    return undef;
-  }
+    my @stat = stat($dir) ;
+    if (@stat == 0) {
+        throw EBox::Exceptions::External (__x("Cannot stat dir: {dir}. This may mean that the directory does not exist or the permissions forbid access to it", dir => $dir)) if $throwException;
+        return undef;
+    }
 
-  if ($< != $stat[4]) {
-    throw EBox::Exceptions::External(__x('The directory {dir} is not private; because it is owned by another user', dir => $dir)) if $throwException;
-  }
-  my $perm = sprintf ("%04o\n", $stat[2] & 07777);
-  unless ($perm =~ /.700/) {
-    throw EBox::Exceptions::External(('The directory {dir} is not private; because it has not restrictive permissions', dir => $dir)) if $throwException;
-    return undef;
-  }
+    if ($< != $stat[4]) {
+        throw EBox::Exceptions::External(__x('The directory {dir} is not private; because it is owned by another user', dir => $dir)) if $throwException;
+    }
+    my $perm = sprintf ("%04o\n", $stat[2] & 07777);
+    unless ($perm =~ /.700/) {
+        throw EBox::Exceptions::External(('The directory {dir} is not private; because it has not restrictive permissions', dir => $dir)) if $throwException;
+        return undef;
+    }
 }
 
 
@@ -725,11 +712,11 @@ sub isPrivateDir
 #
 sub isANumber # (value)
 {
-        my $value = shift;
+    my $value = shift;
 
-        ($value =~ /^-?[\d]+$/) and return 1;
+    ($value =~ /^-?[\d]+$/) and return 1;
 
-        return undef;
+    return undef;
 }
 
 # Function: isZeroOrNaturalNumber
@@ -745,11 +732,11 @@ sub isANumber # (value)
 #
 sub isZeroOrNaturalNumber # (value)
 {
-        my $value = shift;
+    my $value = shift;
 
-        ($value =~ /^[\d]+$/) and return 1;
+    ($value =~ /^[\d]+$/) and return 1;
 
-        return undef;
+    return undef;
 }
 
 # Function: checkFilePath
@@ -797,12 +784,12 @@ sub checkFilePath # (filePath, name)
 #  true if the parameter is sintaxically correct and an absolute path, undef otherwise.
 sub checkAbsoluteFilePath
 {
-   my ($filePath, $name) = @_;
+    my ($filePath, $name) = @_;
 
-   my $isValidPath = checkFilePath($filePath, $name);
-   $isValidPath or return undef;
+    my $isValidPath = checkFilePath($filePath, $name);
+    $isValidPath or return undef;
 
-   if ( ( $filePath =~ m{^[^/]} )  or ( $filePath =~ m{/\.+/} ) ) {
+    if ( ( $filePath =~ m{^[^/]} )  or ( $filePath =~ m{/\.+/} ) ) {
         if ($name) {
             throw EBox::Exceptions::InvalidData
                 ('data' => $name, 'value' => $filePath, 'advice' => __("The file path must be absolute") );
@@ -810,9 +797,9 @@ sub checkAbsoluteFilePath
         else {
             return undef;
         }
-   }
+    }
 
-   return 1;
+    return 1;
 }
 
 1;
